#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# c.durr - swerc - 2017

# Menu Tour
# Dynamic programming with N*C*B states A[c, r, b] = minimum time for a tour
# that covers courses from 0 to c, ends in restaurant r and costs b Euros.
# update time O(N), complexity O(N^2 C B) which is ok

# from numpy import full  # do not use numpy, way too slow

def full(dim, default):
    a, b, c = dim
    return [[[default for _ in range(c)] for _ in range(b)] for _ in range(a)]

def readInt():      return int(input())
def readInts():     return map(int, input().split())

def array3d(a,b,c, default=None):
    return [[[default for _ in range(c)] for _ in range(b)] for _ in range(a)]

def array2d(a,b, default=None):
    return [[default for _ in range(b)] for _ in range(a)]

def solve(C, R, B, X, Y, P):
    restaurants = range(R)
    courses = range(C)
    budget = range(B + 1)
    A = full((C, R, B+1), -1)
    dist = array2d(R, R)
    for i in range(R):           # pre-compute distances, saves 30% of running time
        for j in range(R):
            dist[i][j] = abs(X[i] - X[j]) + abs(Y[i] - Y[j])
    # base step c = 0
    for r in restaurants:
        b = P[r][0]
        if b != 0:
            A[0][r][b] = 0
    # induction step
    for c in range(1, C):
        for r in restaurants:
            for b in budget:
                a = P[r][c]
                if 1 <= a <= b:
                    for i in restaurants:
                        before = A[c - 1][i][b - a]
                        alternative = before + dist[i][r]
                        if before != -1 and (A[c][r][b] == -1 or A[c][r][b] > alternative):
                            A[c][r][b] = alternative
    # extract optimum
    best = -1
    for r in restaurants:
        for b in budget:
            if A[C-1][r][b] != -1 and (best == -1 or best > A[C-1][r][b]):
                best = A[C-1][r][b]
    return best


C, R, B = readInts()
X = []
Y = []
P = []
for i in range(R):
    tab = list(readInts())
    X.append(tab[0])
    Y.append(tab[1])
    P.append(tab[2:])
    assert(len(tab[2:]) == C)
print(solve(C, R, B, X, Y, P))
